==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/outputs/GetDataSetLogicalTableMapDataTransform.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property castColumnTypeOperations
 * @property createColumnsOperations
 * @property filterOperations
 * @property projectOperations
 * @property renameColumnOperations
 * @property tagColumnOperations
 * @property untagColumnOperations
 */
public data class GetDataSetLogicalTableMapDataTransform(
    public val castColumnTypeOperations:
    List<GetDataSetLogicalTableMapDataTransformCastColumnTypeOperation>,
    public val createColumnsOperations:
    List<GetDataSetLogicalTableMapDataTransformCreateColumnsOperation>,
    public val filterOperations: List<GetDataSetLogicalTableMapDataTransformFilterOperation>,
    public val projectOperations: List<GetDataSetLogicalTableMapDataTransformProjectOperation>,
    public val renameColumnOperations:
    List<GetDataSetLogicalTableMapDataTransformRenameColumnOperation>,
    public val tagColumnOperations: List<GetDataSetLogicalTableMapDataTransformTagColumnOperation>,
    public val untagColumnOperations:
    List<GetDataSetLogicalTableMapDataTransformUntagColumnOperation>,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.quicksight.outputs.GetDataSetLogicalTableMapDataTransform):
            GetDataSetLogicalTableMapDataTransform = GetDataSetLogicalTableMapDataTransform(
            castColumnTypeOperations = javaType.castColumnTypeOperations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.quicksight.kotlin.outputs.GetDataSetLogicalTableMapDataTransformCastColumnTypeOperation.Companion.toKotlin(args0)
                })
            }),
            createColumnsOperations = javaType.createColumnsOperations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.quicksight.kotlin.outputs.GetDataSetLogicalTableMapDataTransformCreateColumnsOperation.Companion.toKotlin(args0)
                })
            }),
            filterOperations = javaType.filterOperations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.quicksight.kotlin.outputs.GetDataSetLogicalTableMapDataTransformFilterOperation.Companion.toKotlin(args0)
                })
            }),
            projectOperations = javaType.projectOperations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.quicksight.kotlin.outputs.GetDataSetLogicalTableMapDataTransformProjectOperation.Companion.toKotlin(args0)
                })
            }),
            renameColumnOperations = javaType.renameColumnOperations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.quicksight.kotlin.outputs.GetDataSetLogicalTableMapDataTransformRenameColumnOperation.Companion.toKotlin(args0)
                })
            }),
            tagColumnOperations = javaType.tagColumnOperations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.quicksight.kotlin.outputs.GetDataSetLogicalTableMapDataTransformTagColumnOperation.Companion.toKotlin(args0)
                })
            }),
            untagColumnOperations = javaType.untagColumnOperations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.quicksight.kotlin.outputs.GetDataSetLogicalTableMapDataTransformUntagColumnOperation.Companion.toKotlin(args0)
                })
            }),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/outputs/GetDataSetLogicalTableMapDataTransform.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property castColumnTypeOperations
 * @property createColumnsOperations
 * @property filterOperations
 * @property projectOperations
 * @property renameColumnOperations
 * @property tagColumnOperations
 * @property untagColumnOperations
 */
public data class GetDataSetLogicalTableMapDataTransform(
    public val castColumnTypeOperations: List<GetDataSetLogicalTableMapDataTransformCastColumnTypeOperation>,
    public val createColumnsOperations: List<GetDataSetLogicalTableMapDataTransformCreateColumnsOperation>,
    public val filterOperations: List<GetDataSetLogicalTableMapDataTransformFilterOperation>,
    public val projectOperations: List<GetDataSetLogicalTableMapDataTransformProjectOperation>,
    public val renameColumnOperations: List<GetDataSetLogicalTableMapDataTransformRenameColumnOperation>,
    public val tagColumnOperations: List<GetDataSetLogicalTableMapDataTransformTagColumnOperation>,
    public val untagColumnOperations: List<GetDataSetLogicalTableMapDataTransformUntagColumnOperation>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.quicksight.outputs.GetDataSetLogicalTableMapDataTransform): GetDataSetLogicalTableMapDataTransform = GetDataSetLogicalTableMapDataTransform(
            castColumnTypeOperations = javaType.castColumnTypeOperations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.quicksight.kotlin.outputs.GetDataSetLogicalTableMapDataTransformCastColumnTypeOperation.Companion.toKotlin(args0)
                })
            }),
            createColumnsOperations = javaType.createColumnsOperations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.quicksight.kotlin.outputs.GetDataSetLogicalTableMapDataTransformCreateColumnsOperation.Companion.toKotlin(args0)
                })
            }),
            filterOperations = javaType.filterOperations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.quicksight.kotlin.outputs.GetDataSetLogicalTableMapDataTransformFilterOperation.Companion.toKotlin(args0)
                })
            }),
            projectOperations = javaType.projectOperations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.quicksight.kotlin.outputs.GetDataSetLogicalTableMapDataTransformProjectOperation.Companion.toKotlin(args0)
                })
            }),
            renameColumnOperations = javaType.renameColumnOperations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.quicksight.kotlin.outputs.GetDataSetLogicalTableMapDataTransformRenameColumnOperation.Companion.toKotlin(args0)
                })
            }),
            tagColumnOperations = javaType.tagColumnOperations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.quicksight.kotlin.outputs.GetDataSetLogicalTableMapDataTransformTagColumnOperation.Companion.toKotlin(args0)
                })
            }),
            untagColumnOperations = javaType.untagColumnOperations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.quicksight.kotlin.outputs.GetDataSetLogicalTableMapDataTransformUntagColumnOperation.Companion.toKotlin(args0)
                })
            }),
        )
    }
}
